@@ -1,6 +1,6 @@
 package SPOPS::Exception;
 
-# $Id: Exception.pm,v 2.0 2002/03/19 04:00:00 lachoy Exp $
+# $Id: Exception.pm,v 2.1 2002/04/29 12:50:23 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor Exporter );
@@ -8,7 +8,7 @@ use overload '""' => \&stringify;
 use Devel::StackTrace;
 use SPOPS::Error;
 
-$SPOPS::Exception::VERSION   = substr(q$Revision: 2.0 $, 10);
+$SPOPS::Exception::VERSION   = substr(q$Revision: 2.1 $, 10);
 @SPOPS::Exception::EXPORT_OK = qw( spops_error );
 
 use constant DEBUG => 0;
@@ -20,7 +20,7 @@ SPOPS::Exception->mk_accessors( @FIELDS );
 ########################################
 # SHORTCUT
 
-sub spops_error { return SPOPS::Exception->throw( @_ ) }
+sub spops_error { goto &throw( 'SPOPS::Exception', @_ ) }
 
 
 ########################################
