@@ -1,15 +1,15 @@
 package SPOPS::Tie::StrictField;
 
-# $Id: StrictField.pm,v 1.14 2002/01/02 02:37:02 lachoy Exp $
+# $Id: StrictField.pm,v 2.0 2002/03/19 04:00:04 lachoy Exp $
 
 use strict;
+use base  qw( SPOPS::Tie );
+
 use Carp       qw( carp );
 use SPOPS::Tie qw( IDX_DATA IDX_CHANGE IDX_INTERNAL IDX_TEMP  
                    IDX_CHECK_FIELDS $PREFIX_TEMP $PREFIX_INTERNAL );
 
-@SPOPS::Tie::StrictField::ISA      = qw( SPOPS::Tie );
-$SPOPS::Tie::StrictField::VERSION  = '1.90';
-$SPOPS::Tie::StrictField::Revision = substr(q$Revision: 1.14 $, 10);
+$SPOPS::Tie::StrictField::VERSION  = substr(q$Revision: 2.0 $, 10);
 
 *_w    = *SPOPS::_w;
 *DEBUG = *SPOPS::DEBUG;
